@@ -4,14 +4,20 @@ Created on Tue Mar 31 12:50:44 2020
 
 """
 import os
+from time import sleep
 from PyQt5.QtQml import qmlRegisterType
 
 # import Audio here so people can import it without
 # going int the audio package to access it
 from .audio import Audio
+from .video import Video
 from soloman.pyqt_inter_audio import QAudio
 from soloman.pyqt_inter_video import QVideo
 
+def FPS_24():
+    sleep(1/40)
+    return True
+
 def register():
 
     directory = __file__.replace('\\soloman\\__init__.py', '')
@@ -23,11 +29,10 @@ def register():
     # Delete the contents of our Temp folder
     path = os.path.join(os.environ['TEMP'], 'soloman', 'converts')
     if os.path.exists(path):
-        print('apth: ', path)
         os.system('RD "' + path + '" /S /Q')
 
-    qmlRegisterType(QAudio, 'soloman', 2, 1, 'SAudio')
-    qmlRegisterType(QVideo, 'soloman', 2, 1, 'QVideo')
+    qmlRegisterType(QAudio, 'soloman', 2, 2, 'SAudio')
+    qmlRegisterType(QVideo, 'soloman', 2, 2, 'QVideo')
 
 
 register()
